searchData={"content_type":"text/markdown","items":[{"doc":"DBCluster provides a database backed method of clustering your nodes. At startup, each node will query the database for other nodes and try to connect to them (while adding themselves to the database). In this manner you can add new nodes without having to update lists or use things like kubernetes.\n\nAside from the initial setup it is not expected you will need to interface with the DBCluster app, the majority of functions exported are related to querying the database table used by the app.","ref":"DBCluster.html","title":"DBCluster","type":"module"},{"doc":"```elixir\ndef deps do\n  [\n    {:db_cluster, \"~> 0.0.1\"}\n  ]\nend\n```\n\nNow add a migration\n```bash\nmix ecto.gen.migration add_db_cluster_tables\n```\n\nOpen the generated migration and add the below code:\n```elixir\ndefmodule MyApp.Repo.Migrations.AddDBClusterTables do\n  use Ecto.Migration\n\n  def up do\n    DBCluster.Migration.up()\n  end\n\n  # We specify `version: 1` in `down`, ensuring that we'll roll all the way back down if\n  # necessary, regardless of which version we've migrated `up` to.\n  def down do\n    DBCluster.Migration.down(version: 1)\n  end\nend\n```\n\nFinally, update your config to link the repo:\n```\nconfig :db_cluster,\n  repo: MyApp.Repo\n```","ref":"DBCluster.html#module-installation","title":"Installation - DBCluster","type":"module"},{"doc":"You may find the cluster server launching causes issues in tests, you can disable it via\nconfig with:\n```\nconfig :db_cluster,\n  enabled: false\n```","ref":"DBCluster.html#module-configs","title":"Configs - DBCluster","type":"module"},{"doc":"You can optionally set one or more functions to be called when a cluster join takes place as per the below config option.\n```\nconfig :db_cluster,\n  db_cluster_post_join_functions: [&func1/0, &func2/0]\n```","ref":"DBCluster.html#module-post-join-functions","title":"Post join functions - DBCluster","type":"module"},{"doc":"","ref":"DBCluster.html#change_cluster_member/2","title":"DBCluster.change_cluster_member/2","type":"function"},{"doc":"","ref":"DBCluster.html#create_cluster_member/1","title":"DBCluster.create_cluster_member/1","type":"function"},{"doc":"","ref":"DBCluster.html#delete_cluster_member/1","title":"DBCluster.delete_cluster_member/1","type":"function"},{"doc":"","ref":"DBCluster.html#get_cluster_member/1","title":"DBCluster.get_cluster_member/1","type":"function"},{"doc":"","ref":"DBCluster.html#get_cluster_member!/1","title":"DBCluster.get_cluster_member!/1","type":"function"},{"doc":"","ref":"DBCluster.html#list_cluster_members/1","title":"DBCluster.list_cluster_members/1","type":"function"},{"doc":"","ref":"DBCluster.html#update_cluster_member/2","title":"DBCluster.update_cluster_member/2","type":"function"},{"doc":"# Match\nA clustering method making use of a database to setup and update the cluster.","ref":"DBCluster.ClusterMember.html","title":"DBCluster.ClusterMember","type":"module"},{"doc":"* `:host` - The host name, e.g. \"server1.host.co.uk\"","ref":"DBCluster.ClusterMember.html#module-attributes","title":"Attributes - DBCluster.ClusterMember","type":"module"},{"doc":"Builds a changeset based on the `struct` and `params`.","ref":"DBCluster.ClusterMember.html#changeset/2","title":"DBCluster.ClusterMember.changeset/2","type":"function"},{"doc":"","ref":"DBCluster.ClusterMember.html#t:id/0","title":"DBCluster.ClusterMember.id/0","type":"type"},{"doc":"","ref":"DBCluster.ClusterMember.html#t:t/0","title":"DBCluster.ClusterMember.t/0","type":"type"},{"doc":"Library of ClusterMember functions used to query database contents.","ref":"DBCluster.ClusterMemberLib.html","title":"DBCluster.ClusterMemberLib","type":"module"},{"doc":"Returns an `%Ecto.Changeset{}` for tracking cluster_member changes.","ref":"DBCluster.ClusterMemberLib.html#change_cluster_member/2","title":"DBCluster.ClusterMemberLib.change_cluster_member/2","type":"function"},{"doc":"iex> change_cluster_member(cluster_member)\n    %Ecto.Changeset{data: %ClusterMember{}}","ref":"DBCluster.ClusterMemberLib.html#change_cluster_member/2-examples","title":"Examples - DBCluster.ClusterMemberLib.change_cluster_member/2","type":"function"},{"doc":"Creates a cluster_member.","ref":"DBCluster.ClusterMemberLib.html#create_cluster_member/1","title":"DBCluster.ClusterMemberLib.create_cluster_member/1","type":"function"},{"doc":"iex> create_cluster_member(%{field: value})\n    {:ok, %ClusterMember{}}\n\n    iex> create_cluster_member(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"DBCluster.ClusterMemberLib.html#create_cluster_member/1-examples","title":"Examples - DBCluster.ClusterMemberLib.create_cluster_member/1","type":"function"},{"doc":"Deletes a cluster_member.","ref":"DBCluster.ClusterMemberLib.html#delete_cluster_member/1","title":"DBCluster.ClusterMemberLib.delete_cluster_member/1","type":"function"},{"doc":"iex> delete_cluster_member(cluster_member)\n    {:ok, %ClusterMember{}}\n\n    iex> delete_cluster_member(cluster_member)\n    {:error, %Ecto.Changeset{}}","ref":"DBCluster.ClusterMemberLib.html#delete_cluster_member/1-examples","title":"Examples - DBCluster.ClusterMemberLib.delete_cluster_member/1","type":"function"},{"doc":"Gets a single cluster_member.\n\nReturns nil if the ClusterMember does not exist.","ref":"DBCluster.ClusterMemberLib.html#get_cluster_member/2","title":"DBCluster.ClusterMemberLib.get_cluster_member/2","type":"function"},{"doc":"iex> get_cluster_member(123)\n    %ClusterMember{}\n\n    iex> get_cluster_member(456)\n    nil","ref":"DBCluster.ClusterMemberLib.html#get_cluster_member/2-examples","title":"Examples - DBCluster.ClusterMemberLib.get_cluster_member/2","type":"function"},{"doc":"Gets a single cluster_member.\n\nRaises `Ecto.NoResultsError` if the ClusterMember does not exist.","ref":"DBCluster.ClusterMemberLib.html#get_cluster_member!/2","title":"DBCluster.ClusterMemberLib.get_cluster_member!/2","type":"function"},{"doc":"iex> get_cluster_member!(123)\n    %ClusterMember{}\n\n    iex> get_cluster_member!(456)\n    ** (Ecto.NoResultsError)","ref":"DBCluster.ClusterMemberLib.html#get_cluster_member!/2-examples","title":"Examples - DBCluster.ClusterMemberLib.get_cluster_member!/2","type":"function"},{"doc":"Returns the list of cluster_members.","ref":"DBCluster.ClusterMemberLib.html#list_cluster_members/1","title":"DBCluster.ClusterMemberLib.list_cluster_members/1","type":"function"},{"doc":"iex> list_cluster_members()\n    [%ClusterMember{}, ...]","ref":"DBCluster.ClusterMemberLib.html#list_cluster_members/1-examples","title":"Examples - DBCluster.ClusterMemberLib.list_cluster_members/1","type":"function"},{"doc":"Updates a cluster_member.","ref":"DBCluster.ClusterMemberLib.html#update_cluster_member/2","title":"DBCluster.ClusterMemberLib.update_cluster_member/2","type":"function"},{"doc":"iex> update_cluster_member(cluster_member, %{field: new_value})\n    {:ok, %ClusterMember{}}\n\n    iex> update_cluster_member(cluster_member, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"DBCluster.ClusterMemberLib.html#update_cluster_member/2-examples","title":"Examples - DBCluster.ClusterMemberLib.update_cluster_member/2","type":"function"},{"doc":"The cluster manager for handling adding nodes to a cluster.","ref":"DBCluster.ClusterMemberServer.html","title":"DBCluster.ClusterMemberServer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"DBCluster.ClusterMemberServer.html#child_spec/1","title":"DBCluster.ClusterMemberServer.child_spec/1","type":"function"},{"doc":"","ref":"DBCluster.ClusterMemberServer.html#start_link/2","title":"DBCluster.ClusterMemberServer.start_link/2","type":"function"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}